braindecode.datautil.create_from_X_y
====================================

.. currentmodule:: braindecode.datautil

.. autofunction:: create_from_X_y

.. include:: braindecode.datautil.create_from_X_y.examples

.. raw:: html

    <div style='clear:both'></div>